==> country_picker-2.0.10.tar.gz: lib/src/res/strings/tr.dart <==
Map<String, String> tr = {
  "AF": "Afganistan",
  "AX": "Åland Adaları",
  "AL": "Arnavutluk",
  "DZ": "Cezayir",
  "AS": "Amerikan Samoası",
  "AD": "Andora",
  "AO": "Angola",
  "AI": "Anguilla",
  "AG": "Antigua ve Barbuda",
  "AR": "Arjantin",
  "AM": "Ermenistan",
  "AW": "Aruba",
  "AC": "Yükseliş Adası",
  "AU": "Avustralya",
  "AT": "Avusturya",
  "AZ": "Azerbaycan",
  "BS": "Bahamalar",
  "BH": "Bahreyn",
  "BD": "Bangladeş",
  "BB": "Barbados",
  "BY": "Beyaz Rusya",
  "BE": "Belçika",
  "BZ": "Beliz",
  "BJ": "Benin",
  "BM": "Bermuda",
  "BT": "Butan",
  "BO": "Bolivya",
  "BA": "Bosna Hersek",
  "BW": "Botsvana",
  "BR": "Brezilya",
  "IO": "Britanya Hint Okyanusu Toprakları",
  "VG": "İngiliz Virgin Adaları",
  "BN": "Bruney",
  "BG": "Bulgaristan",
  "BF": "Burkina Faso",
  "BI": "Burundi",
  "KH": "Kamboçya",
  "CM": "Kamerun",
  "CA": "Kanada",
  "CV": "Cape Verde",
  "BQ": "Karayip Hollandası",
  "KY": "Kayman Adaları",
  "CF": "Orta Afrika Cumhuriyeti",
  "TD": "Çad",
  "CL": "Şili",
  "CN": "Çin",
  "CX": "Noel Adası",
  "CC": "Cocos [Keeling] Adaları",
  "CO": "Kolombiya",
  "KM": "Komorlar",
  "CD": "Kongo Demokratik Cumhuriyeti",
  "CG": "Kongo Cumhuriyeti",
  "CK": "Cook Adaları",
  "CR": "Kosta Rika",
  "CI": "Fildişi Sahili",
  "İK": "Hırvatistan",
  "CU": "Küba",
  "CW": "Curaçao",
  "CY": "Kıbrıs",
  "CZ": "Çek Cumhuriyeti",
  "DK": "Danimarka",
  "DJ": "Cibuti",
  "DM": "Dominika",
  "DO": "Dominik Cumhuriyeti",
  "TL": "Doğu Timor",
  "EC": "Ekvador",
  "EG": "Mısır",
  "SV": "El Salvador",
  "GQ": "Ekvator Ginesi",
  "ER": "Eritre",
  "EE": "Estonya",
  "ET": "Etiyopya",
  "FK": "Falkland Adaları [Islas Malvinas]",
  "FO": "Faroe Adaları",
  "FJ": "Fiji",
  "FI": "Finlandiya",
  "FR": "Fransa",
  "GF": "Fransız Guyanası",
  "PF": "Fransız Polinezyası",
  "GA": "Gabon",
  "GM": "Gambiya",
  "GE": "Gürcistan",
  "DE": "Almanya",
  "GH": "Gana",
  "GI": "Cebelitarık",
  "GR": "Yunanistan",
  "GL": "Grönland",
  "GD": "Grenada",
  "GP": "Guadelupe",
  "GU": "Guam",
  "GT": "Guatemala",
  "GG": "Guernsey",
  "GN": "Gine Conakry",
  "GW": "Gine-Bissau",
  "GY": "Guyana",
  "HT": "Haiti",
  "HM": "Heard Adası ve McDonald Adaları",
  "HN": "Honduras",
  "HK": "Hong Kong",
  "HU": "Macaristan",
  "IS": "İzlanda",
  "IN": "Hindistan",
  "ID": "Endonezya",
  "IR": "İran",
  "IQ": "Irak",
  "IE": "İrlanda",
  "IM": "Man Adası",
  "IL": "İsrail",
  "BT": "İtalya",
  "JM": "Jamaika",
  "JP": "Japonya",
  "JE": "Forma",
  "JO": "Ürdün",
  "KZ": "Kazakistan",
  "KE": "Kenya",
  "KI": "Kiribati",
  "XK": "Kosova",
  "KW": "Kuveyt",
  "KG": "Kırgızistan",
  "LA": "Laos",
  "LV": "Letonya",
  "LB": "Lübnan",
  "LS": "Lezoto",
  "LR": "Liberya",
  "LY": "Libya",
  "LI": "Lihtenştayn",
  "LT": "Litvanya",
  "LU": "Lüksemburg",
  "MO": "Makao",
  "MK": "Makedonya",
  "MG": "Madagaskar",
  "MW": "Malavi",
  "BEN": "Malezya",
  "MV": "Maldivler",
  "ML": "Mali",
  "MT": "Malta",
  "MH": "Marshall Adaları",
  "MQ": "Martinik",
  "BAY": "Moritanya",
  "MU": "Mauritius",
  "YT": "Mayotte",
  "MX": "Meksika",
  "FM": "Mikronezya",
  "MD": "Moldova",
  "MC": "Monako",
  "MN": "Moğolistan",
  "Ben": "Karadağ",
  "MS": "Montserrat",
  "MA": "Fas",
  "MZ": "Mozambik",
  "AA": "Myanmar [Burma]",
  "NA": "Namibya",
  "NR": "Nauru",
  "NP": "Nepal",
  "NL": "Hollanda",
  "NC": "Yeni Kaledonya",
  "NZ": "Yeni Zelanda",
  "NI": "Nikaragua",
  "NE": "Nijer",
  "NG": "Nijerya",
  "NU": "Niue",
  "NF": "Norfolk Adası",
  "KP": "Kuzey Kore",
  "MP": "Kuzey Mariana Adaları",
  "HAYIR": "Norveç",
  "OM": "Umman",
  "PK": "Pakistan",
  "PW": "Palau",
  "PS": "Filistin Toprakları",
  "PA": "Panama",
  "PG": "Papua Yeni Gine",
  "PY": "Paraguay",
  "PE": "Peru",
  "PH": "Filipinler",
  "PL": "Polonya",
  "PT": "Portekiz",
  "PR": "Porto Riko",
  "QA": "Katar",
  "RE": "Reunion",
  "RO": "Romanya",
  "RU": "Rusya",
  "RW": "Ruanda",
  "BL": "Aziz Barthelemy",
  "SH": "Aziz Helena",
  "KN": "Aziz Kitts",
  "LC": "Aziz Lucia",
  "MF": "Aziz Martin",
  "PM": "Saint Pierre ve Miquelon",
  "VC": "St. Vincent",
  "WS": "Samoa",
  "SM": "San Marino",
  "ST": "São Tomé ve Principe",
  "SA": "Suudi Arabistan",
  "SN": "Senegal",
  "RS": "Sırbistan",
  "SC": "Seyşeller",
  "SL": "Sierra Leone",
  "SG": "Singapur",
  "SX": "Sint Maarten",
  "SK": "Slovakya",
  "SI": "Slovenya",
  "SB": "Süleyman Adaları",
  "SO": "Somali",
  "ZA": "Güney Afrika",
  "GS": "Güney Georgia ve Güney Sandwich Adaları",
  "KR": "Güney Kore",
  "SS": "Güney Sudan",
  "ES": "İspanya",
  "LK": "Sri Lanka",
  "SD": "Sudan",
  "SR": "Surinam",
  "SJ": "Svalbard ve Jan Mayen",
  "SZ": "Svaziland",
  "SE": "İsveç",
  "CH": "İsviçre",
  "SY": "Suriye",
  "TW": "Tayvan",
  "TJ": "Tacikistan",
  "TZ": "Tanzanya",
  "TH": "Tayland",
  "TG": "Togo",
  "TK": "Tokelau",
  "TO": "Tonga",
  "TT": "Trinidad/Tobago",
  "TN": "Tunus",
  "TR": "Türkiye",
  "TM": "Türkmenistan",
  "TC": "Turks ve Caicos Adaları",
  "TV": "Tuvalı",
  "VI": "ABD Virjin Adaları",
  "UG": "Uganda",
  "UA": "Ukrayna",
  "AE": "Birleşik Arap Emirlikleri",
  "GB": "Birleşik Krallık",
  "ABD": "Amerika Birleşik Devletleri",
  "UY": "Uruguay",
  "UZ": "Özbekistan",
  "VU": "Vanuatu",
  "VA": "Vatikan Şehri",
  "VE": "Venezuela",
  "VN": "Vietnam",
  "WF": "Wallis ve Futuna",
  "EH": "Batı Sahra",
  "YE": "Yemen",
  "ZM": "Zambiya",
  "ZW": "Zimbabve",
  "search": "Arama",
};

==> country_picker-2.0.22.tar.gz: lib/src/res/strings/tr.dart <==
Map<String, String> tr = {
  "AF": "Afganistan",
  "AX": "Åland Adaları",
  "AL": "Arnavutluk",
  "DZ": "Cezayir",
  "AS": "Amerikan Samoası",
  "AD": "Andora",
  "AO": "Angola",
  "AI": "Anguilla",
  "AG": "Antigua ve Barbuda",
  "AR": "Arjantin",
  "AM": "Ermenistan",
  "AW": "Aruba",
  "AC": "Yükseliş Adası",
  "AU": "Avustralya",
  "AT": "Avusturya",
  "AZ": "Azerbaycan",
  "BS": "Bahamalar",
  "BH": "Bahreyn",
  "BD": "Bangladeş",
  "BB": "Barbados",
  "BY": "Beyaz Rusya",
  "BE": "Belçika",
  "BZ": "Beliz",
  "BJ": "Benin",
  "BM": "Bermuda",
  "BT": "Butan",
  "BO": "Bolivya",
  "BA": "Bosna Hersek",
  "BW": "Botsvana",
  "BR": "Brezilya",
  "IO": "Britanya Hint Okyanusu Toprakları",
  "VG": "İngiliz Virgin Adaları",
  "BN": "Bruney",
  "BG": "Bulgaristan",
  "BF": "Burkina Faso",
  "BI": "Burundi",
  "KH": "Kamboçya",
  "CM": "Kamerun",
  "CA": "Kanada",
  "CV": "Cape Verde",
  "BQ": "Karayip Hollandası",
  "KY": "Kayman Adaları",
  "CF": "Orta Afrika Cumhuriyeti",
  "TD": "Çad",
  "CL": "Şili",
  "CN": "Çin",
  "CX": "Noel Adası",
  "CC": "Cocos [Keeling] Adaları",
  "CO": "Kolombiya",
  "KM": "Komorlar",
  "CD": "Kongo Demokratik Cumhuriyeti",
  "CG": "Kongo Cumhuriyeti",
  "CK": "Cook Adaları",
  "CR": "Kosta Rika",
  "CI": "Fildişi Sahili",
  "İK": "Hırvatistan",
  "CU": "Küba",
  "CW": "Curaçao",
  "CY": "Kıbrıs",
  "CZ": "Çek Cumhuriyeti",
  "DK": "Danimarka",
  "DJ": "Cibuti",
  "DM": "Dominika",
  "DO": "Dominik Cumhuriyeti",
  "TL": "Doğu Timor",
  "EC": "Ekvador",
  "EG": "Mısır",
  "SV": "El Salvador",
  "GQ": "Ekvator Ginesi",
  "ER": "Eritre",
  "EE": "Estonya",
  "ET": "Etiyopya",
  "FK": "Falkland Adaları [Islas Malvinas]",
  "FO": "Faroe Adaları",
  "FJ": "Fiji",
  "FI": "Finlandiya",
  "FR": "Fransa",
  "GF": "Fransız Guyanası",
  "PF": "Fransız Polinezyası",
  "GA": "Gabon",
  "GM": "Gambiya",
  "GE": "Gürcistan",
  "DE": "Almanya",
  "GH": "Gana",
  "GI": "Cebelitarık",
  "GR": "Yunanistan",
  "GL": "Grönland",
  "GD": "Grenada",
  "GP": "Guadelupe",
  "GU": "Guam",
  "GT": "Guatemala",
  "GG": "Guernsey",
  "GN": "Gine Conakry",
  "GW": "Gine-Bissau",
  "GY": "Guyana",
  "HT": "Haiti",
  "HM": "Heard Adası ve McDonald Adaları",
  "HN": "Honduras",
  "HK": "Hong Kong",
  "HU": "Macaristan",
  "IS": "İzlanda",
  "IN": "Hindistan",
  "ID": "Endonezya",
  "IR": "İran",
  "IQ": "Irak",
  "IE": "İrlanda",
  "IM": "Man Adası",
  "IL": "İsrail",
  "IT": "İtalya",
  "JM": "Jamaika",
  "JP": "Japonya",
  "JE": "Forma",
  "JO": "Ürdün",
  "KZ": "Kazakistan",
  "KE": "Kenya",
  "KI": "Kiribati",
  "XK": "Kosova",
  "KW": "Kuveyt",
  "KG": "Kırgızistan",
  "LA": "Laos",
  "LV": "Letonya",
  "LB": "Lübnan",
  "LS": "Lezoto",
  "LR": "Liberya",
  "LY": "Libya",
  "LI": "Lihtenştayn",
  "LT": "Litvanya",
  "LU": "Lüksemburg",
  "MO": "Makao",
  "MK": "Makedonya",
  "MG": "Madagaskar",
  "MW": "Malavi",
  "BEN": "Malezya",
  "MV": "Maldivler",
  "ML": "Mali",
  "MT": "Malta",
  "MH": "Marshall Adaları",
  "MQ": "Martinik",
  "BAY": "Moritanya",
  "MU": "Mauritius",
  "YT": "Mayotte",
  "MX": "Meksika",
  "FM": "Mikronezya",
  "MD": "Moldova",
  "MC": "Monako",
  "MN": "Moğolistan",
  "Ben": "Karadağ",
  "MS": "Montserrat",
  "MA": "Fas",
  "MZ": "Mozambik",
  "AA": "Myanmar [Burma]",
  "NA": "Namibya",
  "NR": "Nauru",
  "NP": "Nepal",
  "NL": "Hollanda",
  "NC": "Yeni Kaledonya",
  "NZ": "Yeni Zelanda",
  "NI": "Nikaragua",
  "NE": "Nijer",
  "NG": "Nijerya",
  "NU": "Niue",
  "NF": "Norfolk Adası",
  "KP": "Kuzey Kore",
  "MP": "Kuzey Mariana Adaları",
  "HAYIR": "Norveç",
  "OM": "Umman",
  "PK": "Pakistan",
  "PW": "Palau",
  "PS": "Filistin Toprakları",
  "PA": "Panama",
  "PG": "Papua Yeni Gine",
  "PY": "Paraguay",
  "PE": "Peru",
  "PH": "Filipinler",
  "PL": "Polonya",
  "PT": "Portekiz",
  "PR": "Porto Riko",
  "QA": "Katar",
  "RE": "Reunion",
  "RO": "Romanya",
  "RU": "Rusya",
  "RW": "Ruanda",
  "BL": "Aziz Barthelemy",
  "SH": "Aziz Helena",
  "KN": "Aziz Kitts",
  "LC": "Aziz Lucia",
  "MF": "Aziz Martin",
  "PM": "Saint Pierre ve Miquelon",
  "VC": "St. Vincent",
  "WS": "Samoa",
  "SM": "San Marino",
  "ST": "São Tomé ve Principe",
  "SA": "Suudi Arabistan",
  "SN": "Senegal",
  "RS": "Sırbistan",
  "SC": "Seyşeller",
  "SL": "Sierra Leone",
  "SG": "Singapur",
  "SX": "Sint Maarten",
  "SK": "Slovakya",
  "SI": "Slovenya",
  "SB": "Süleyman Adaları",
  "SO": "Somali",
  "ZA": "Güney Afrika",
  "GS": "Güney Georgia ve Güney Sandwich Adaları",
  "KR": "Güney Kore",
  "SS": "Güney Sudan",
  "ES": "İspanya",
  "LK": "Sri Lanka",
  "SD": "Sudan",
  "SR": "Surinam",
  "SJ": "Svalbard ve Jan Mayen",
  "SZ": "Svaziland",
  "SE": "İsveç",
  "CH": "İsviçre",
  "SY": "Suriye",
  "TW": "Tayvan",
  "TJ": "Tacikistan",
  "TZ": "Tanzanya",
  "TH": "Tayland",
  "TG": "Togo",
  "TK": "Tokelau",
  "TO": "Tonga",
  "TT": "Trinidad/Tobago",
  "TN": "Tunus",
  "TR": "Türkiye",
  "TM": "Türkmenistan",
  "TC": "Turks ve Caicos Adaları",
  "TV": "Tuvalı",
  "VI": "ABD Virjin Adaları",
  "UG": "Uganda",
  "UA": "Ukrayna",
  "AE": "Birleşik Arap Emirlikleri",
  "GB": "Birleşik Krallık",
  "US": "Amerika Birleşik Devletleri",
  "UY": "Uruguay",
  "UZ": "Özbekistan",
  "VU": "Vanuatu",
  "VA": "Vatikan Şehri",
  "VE": "Venezuela",
  "VN": "Vietnam",
  "WF": "Wallis ve Futuna",
  "WW": "Tüm dünya",
  "EH": "Batı Sahra",
  "YE": "Yemen",
  "ZM": "Zambiya",
  "ZW": "Zimbabve",
  "search": "Arama",
};
